@@ -46,17 +46,16 @@ function(object, lambda = seq(-2, 2, 1/10), plotit = TRUE,
          interp = (plotit && (m < 100)), eps = 1/
          50, xlab = expression(lambda), ylab = "log-Likelihood", ...)
 {
-    if(is.null(object$y) || is.null(object$qr))
+    if(is.null(y <- object$y) || is.null(xqr <- object$qr))
         stop(paste(deparse(substitute(object)),
                    "does not have both 'qr' and 'y' components"
                    ))
-    y <- object$y
-    n <- length(y)
     if(any(y <= 0))
         stop("response variable must be positive")
-    xqr <- object$qr
-    logy <- log(y)
-    ydot <- exp(mean(logy))
+    n <- length(y)
+    ## scale y[]  {for accuracy in  y^la - 1 }:
+    y <- y / exp(mean(log(y)))
+    logy <- log(y) # now  ydot = exp(mean(log(y))) == 1
     xl <- loglik <- as.vector(lambda)
     m <- length(xl)
     for(i in 1L:m) {
@@ -64,7 +63,7 @@ function(object, lambda = seq(-2, 2, 1/10), plotit = TRUE,
             yt <- (y^la - 1)/la
         else yt <- logy * (1 + (la * logy)/2 *
                            (1 + (la * logy)/3 * (1 + (la * logy)/4)))
-        loglik[i] <-  - n/2 * log(sum(qr.resid(xqr, yt/ydot^(la - 1))^2))
+        loglik[i] <- - n/2 * log(sum(qr.resid(xqr, yt)^2))
     }
     if(interp) {
         sp <- spline(xl, loglik, n = 100)
